# coding=utf-8
#!/usr/bin/env python3

import click
import os
from .create_app import create_app
from .core.embedding import OpenAIEmbedding
from .core.datasource import QDDataSource
from .core.qa import QABot
from .core.intent import IntentBot


@click.group()
def cli():
    pass


@click.command()
@click.option("--conf", type=str)
def server(conf):
    app = create_app(config_path=conf)
    host = app.config["HOST"]
    port = app.config["PORT"]
    app.run(host, port)


@click.command()
@click.option("--bot_type", type=str)
@click.option("--open_ai_key", type=str)
@click.option("--db", type=str)
@click.option("--file", type=str)
@click.option("--collection", type=str)
def upload(bot_type: str, open_ai_key: str, db: str, file: str, collection: str):
    embedder = OpenAIEmbedding(open_ai_key)
    qdrant_host, qdrant_port = db.split(":")
    qd_ds = QDDataSource(qdrant_host, qdrant_port)

    bot = None

    if bot_type == "qa":
        bot = QABot(qd_ds, embedder, collection, 0, 0)
    elif bot_type == "intent":
        bot = IntentBot(qd_ds, embedder, collection, 0, 0)
    if bot is None:
        print("--bot_type must be specificed as 'qa' or 'intent'")

    if os.path.splitext(file)[1].lower() == ".csv":
        bot.create_collection()
        bot.upload_csv(file)
    else:
        print(f"{file} is not a CSV file.")
        return


cli.add_command(server)
cli.add_command(upload)
# cli.add_command(intent)
