# coding=utf-8

import json

from flask import make_response
from ..core.common import BotPayload

DefaultErrorAnswer = "抱歉，我暂时还不明白您的问题，您可以问问我其他的。"


def wrap_response(f):
    def format_response(*args, **kwargs):
        resp = f(*args, **kwargs)
        flask_resp = make_response(resp.to_dict(), resp.code)
        flask_resp.headers["content-type"] = "application/json"
        return flask_resp

    return format_response


class Response(object):
    def __init__(self, code, message, data):
        self.code = code
        self.message = message
        self.data = data

    def to_dict(self):
        return {"code": self.code, "message": self.message, "data": self.data}


class OK(Response):
    def __init__(self, message, data):
        super(OK, self).__init__(200, message, data)


class BadRequest(Response):
    def __init__(self, message):
        super(BadRequest, self).__init__(400, message, None)


class InternalServerError(Response):
    def __init__(self, message, prompt=""):
        errorAnswer = {"question": prompt, "answer": DefaultErrorAnswer}
        super(InternalServerError, self).__init__(
            500, message, BotPayload.factory(**errorAnswer).to_dict()
        )

class NotFound(Response):
    def __init__(self, message, prompt=""):
        notFoundAnswer = {"question": prompt, "answer": DefaultErrorAnswer}
        super(NotFound, self).__init__(
            404, message, BotPayload.factory(**notFoundAnswer).to_dict()
        )


class Forbidden(Response):
    def __init__(self, message):
        super(Forbidden, self).__init__(403, message, None)


class Raw:
    def __init__(self, code, raw_data):
        if type(raw_data) == dict or type(raw_data) == list:
            self.data = raw_data
            self.code = code
        else:
            raise TypeError("Raw Response Only Support Dict or List Object")

    def to_dict(self):
        return json.dumps(self.data)
