# coding=utf-8

from collections import Counter
from typing import List, Dict
from .datasource import QDDataSource
from .embedding import Embedding
from .common import BotPayload, BaseQDBot


class IntentBot(BaseQDBot):
    def __init__(
        self,
        data_source: QDDataSource,
        embedder: Embedding,
        collection: str,
        score: float,
        limit: int,
    ):
        super(IntentBot, self).__init__(data_source)
        # self.data_source = data_source
        self.embdder = embedder
        self.collection = collection
        self.score = score
        self.limit = limit

    def formatter(self, line: List) -> Dict:
        # line format: 问题，答案, type, 意图
        return BotPayload(question=line[0], answer=int(line[3])).to_dict()

    def complete(self, prompt: str) -> BotPayload:
        points = self.data_source.search(
            prompt,
            self.limit,
            embedder=self.embdder,
            collection=self.collection,
        )
        print(points)

        if points is None or len(points) == 0:
            return None

        payloads = [item.payload for item in points if item.score >= self.score]
        if len(payloads) == 0:
            return None

        answers = [p["answer"] for p in payloads]
        most_common_answer = Counter(answers).most_common(1)[0][0]
        result = list(filter(lambda p: p["answer"] == most_common_answer, payloads))
        return BotPayload.factory(**result[0])
